/* Linux-specific ptrace manipulation routines.
   Copyright (C) 2012 Free Software Foundation, Inc.

   This file is part of GDB.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

#ifdef GDBSERVER
#include "server.h"
#else
#include "defs.h"
#include "gdb_string.h"
#endif

#include "linux-ptrace.h"
#include "linux-procfs.h"

#ifdef HAVE_SELINUX_SELINUX_H
# include <selinux/selinux.h>
#endif /* HAVE_SELINUX_SELINUX_H */

/* Print all possible reasons we could fail to attach PID.  */

void
linux_ptrace_attach_warnings (pid_t pid)
{
  pid_t tracerpid;

  tracerpid = linux_proc_get_tracerpid (pid);
  if (tracerpid > 0)
    warning (_("process %d is already traced by process %d"), (int) pid,
	     (int) tracerpid);

  if (linux_proc_pid_is_zombie (pid))
    warning (_("process %d is a zombie - the process has already terminated"),
	     (int) pid);

  linux_ptrace_create_warnings ();
}

/* Print all possible reasons we could fail to create a traced process.  */

void
linux_ptrace_create_warnings (void)
{
#ifdef HAVE_LIBSELINUX
  /* -1 is returned for errors, 0 if it has no effect, 1 if PTRACE_ATTACH is
     forbidden.  */
  if (security_get_boolean_active ("deny_ptrace") == 1)
    warning (_("the SELinux boolean 'deny_ptrace' is enabled, "
	       "you can disable this process attach protection by: "
	       "(gdb) shell sudo setsebool deny_ptrace=0"));
#endif /* HAVE_LIBSELINUX */
}
